@@ -32,16 +32,14 @@ class SessionPool:
         tasks = []
 
         while len(session_list) > 0:
-            logger.info("session list circle run")
+            logger.debug("session list circle run")
             time_interval = session_interval * (index + 1)
             logger.info(
-                "async start session connect with max_async: %s, and list size: %s"
-                % (self.max_async, len(session_list))
+                "[连接池]最大并发连接数: %s, 启动会话数: %s" % (self.max_async, len(session_list))
             )
             for i in range(self.max_async):
                 if len(session_list) == 0:
                     break
-                logger.info("session list pop session with index %d" % i)
                 tasks.append(
                     asyncio.ensure_future(
                         self._runner(session_list.pop(i), time_interval), loop=loop
@@ -52,15 +50,10 @@ class SessionPool:
         await asyncio.wait(tasks)
 
     async def _runner(self, session, time_interval):
-        logger.info(
-            "run session with session: %s, time_interval: %s" % (session, time_interval)
-        )
         await self.session_manager.new_connect(session, time_interval)
 
     def add(self, session):
-        logger.info("add session: %s" % session)
         self.session_list.append(session)
 
     def close(self):
-        logger.info("session loop closed")
         self.loop.close()
