@@ -3,6 +3,7 @@
 import logging
 import os
 import platform
+import sys
 from logging import FileHandler
 from logging.handlers import TimedRotatingFileHandler
 
@@ -37,12 +38,8 @@ def _getLevel():
 
 
 def getLogger(name=None):
-    print_format = (
-        "%(asctime)s - "
-        "\033[1;33m%(levelname)s: %(name)s - %(filename)s - %(funcName)s(line: %(lineno)s):\033[0m%(message)s"
-        ""
-    )
-    file_format = "%(asctime)s-%(name)s - %(filename)s - %(funcName)s - line %(lineno)s-%(levelname)s - %(message)s"
+    print_format = "\033[1;33m[%(levelname)s] %(funcName)s (%(filename)s:%(lineno)s):\033[0m%(message)s"
+    file_format = "%(asctime)s [%(levelname)s] %(funcName)s (%(filename)s:%(lineno)s): %(message)s"
 
     if name is None:
         logger = logging.getLogger("qqbot")
@@ -50,7 +47,13 @@ def getLogger(name=None):
         logger = logging.getLogger(name)
 
     logging.basicConfig(format=print_format)
-    logger.setLevel(level=_getLevel())
+
+    # 从用户命令行接收是否打印debug日志
+    argv = sys.argv
+    if len(argv) > 1 and argv[1] in ["-d", "--debug"]:
+        logger.setLevel(level=logging.DEBUG)
+    else:
+        logger.setLevel(level=_getLevel())
 
     # FileHandler
     no_log = os.getenv("QQBOT_DISABLE_LOG", "0")
@@ -76,12 +79,9 @@ def getLogger(name=None):
             )
         else:
             file_handler = FileHandler(log_file, encoding="utf-8")
-        logger.debug(
-            "qqbot: dumping log file to {path}".format(path=os.path.realpath(log_file))
-        )
-        file_handler.setLevel(level=_getLevel())
-        file_handler.setFormatter(formatter)
         if len(logger.handlers) == 0:
+            file_handler.setLevel(level=logging.DEBUG)
+            file_handler.setFormatter(formatter)
             logger.addHandler(file_handler)
 
     return logger
